@@ -91,7 +91,7 @@ $lang = array_merge($lang, array(
 	'MAX_AVATAR_SIZE'	=> 'حداکثر ابعاد نماد',
 	'MAX_AVATAR_SIZE_EXPLAIN'	=> 'عرض x ارتفاع بر کمیت پیکسل.',
 	'MAX_FILESIZE'	=> 'حد اکثر حجم نماد',
-	'MAX_FILESIZE_EXPLAIN'	=> 'برای آپلود فایل نماد.',
+	'MAX_FILESIZE_EXPLAIN'	=> 'برای آپلود فایل نماد.اگر با 0 مقداردهی شود (اندازه فایل را بینهایت می کند)، فقط بوسیله تنظیمات پیکربندی PHP توانایی محدودسازی اندازه فایل های آپلودی را دارید.',
 	'MIN_AVATAR_SIZE'	=> 'حداقل ابعاد نماد',
 	'MIN_AVATAR_SIZE_EXPLAIN'	=> 'عرض x ارتفاع بر کمیت پیکسل.',
 	'ACP_MESSAGE_SETTINGS_EXPLAIN'	=> 'در این قسمت شما می توانید تنظیمات پیشفرض برای همه قسمت های پیغام های خصوصی را تغییر دهید.',
@@ -125,8 +125,8 @@ $lang = array_merge($lang, array(
 	'ALLOW_POST_FLASH_EXPLAIN'	=> 'در صورتي که تگ <code>[FLASH]</code> غير فعال شود ، استعمال فايل هاي فلش در پست ها غير ممکن است. لطفا سطوح دسترسي کاربراني را که قصد داريد  آنها را مجاز به استفاده فايل هاي فلش کنيد ، بازنويسي نماييد.',
 	
 	'ENABLE_QUEUE_TRIGGER'			=> 'فعال بودن پست پي در پي',
-	'ENABLE_QUEUE_TRIGGER_EXPLAIN'	=> 'Ability to put registered users posts to post approval if their post count is lower than the specified value below. This setting has no effect on the permission setting for post/topic approval.',
-	'QUEUE_TRIGGER_POSTS'			=> 'Maximum post count for queued posts',
+	'ENABLE_QUEUE_TRIGGER_EXPLAIN'	=> 'توسط این گزینه میتوانید تعداد پست هایی را معین کنید که تا این تعداد مباحث و پست های کاربر به صورت معلق باقی بماند و تا زمانیکه مدیر مربوطه آن را تایید نکند در انجمن نمایش داده نشود. برای غیر فعال کردن این بخش باید سطوح دسترسی تاپیک ها و پست ها را برای گروه ها یا کاربران تغییر دهید',
+	'QUEUE_TRIGGER_POSTS'			=> 'حداکثر تعداد پست جهت رفتن به حالت معلق',
 	'QUEUE_TRIGGER_POSTS_EXPLAIN'	=> 'If queued posts is enabled, this is the post count the user need to reach in order to post without post approval. If the users post count is below this number, the post is stored in the queue automatically.',
 			
 	'BUMP_INTERVAL'	=> 'فاصله بامپ',
@@ -231,44 +231,45 @@ $lang = array_merge($lang, array(
 
 // 3.0.8 www.phpBB.Maghsad.com Changes START
 
-	'ACP_VC_SETTINGS_EXPLAIN'				=> 'Here you can select and configure plugins, which are designed to block automated form submissions by spambots. These plugins typically work by challenging the user with a <em>CAPTCHA</em>, a test which is designed to be difficult for computers to solve.',
-	'AVAILABLE_CAPTCHAS'					=> 'Available plugins',
-	'CAPTCHA_UNAVAILABLE'					=> 'The plugin cannot be selected as its requirements are not met.',
-	'CAPTCHA_GD'							=> 'GD image',
-	'CAPTCHA_GD_3D'							=> 'GD 3D image',
-	'CAPTCHA_GD_FOREGROUND_NOISE'			=> 'Foreground noise',
-	'CAPTCHA_GD_EXPLAIN'					=> 'Uses GD to make a more advanced anti-spambot image.',
-	'CAPTCHA_GD_FOREGROUND_NOISE_EXPLAIN'	=> 'Use foreground noise to make the image harder to read.',
-	'CAPTCHA_GD_X_GRID'						=> 'Background noise x-axis',
-	'CAPTCHA_GD_X_GRID_EXPLAIN'				=> 'Use lower settings of this to make the image harder to read. 0 will disable x-axis background noise.',
-	'CAPTCHA_GD_Y_GRID'						=> 'Background noise y-axis',
-	'CAPTCHA_GD_Y_GRID_EXPLAIN'				=> 'Use lower settings of this to make the image harder to read. 0 will disable y-axis background noise.',
-	'CAPTCHA_GD_WAVE'						=> 'Wave distortion',
-	'CAPTCHA_GD_WAVE_EXPLAIN'				=> 'This applies a wave distortion to the image.',
-	'CAPTCHA_GD_3D_NOISE'					=> 'Add 3D-noise objects',
-	'CAPTCHA_GD_3D_NOISE_EXPLAIN'			=> 'This adds additional objects to the image, over the letters.',
-	'CAPTCHA_GD_FONTS'						=> 'Use different fonts',
-	'CAPTCHA_GD_FONTS_EXPLAIN'				=> 'This setting controls how many different letter shapes are used. You can just use the default shapes or introduce altered letters. Adding lowercase letters is also possible.',
-	'CAPTCHA_FONT_DEFAULT'					=> 'Default',
-	'CAPTCHA_FONT_NEW'						=> 'New Shapes',
-	'CAPTCHA_FONT_LOWER'					=> 'Also use lowercase',
-	'CAPTCHA_NO_GD'							=> 'Simple image',
-	'CAPTCHA_PREVIEW_MSG'					=> 'Your changes have not been saved, this is just a preview.',
-	'CAPTCHA_PREVIEW_EXPLAIN'				=> 'The plugin as it would look like using the current selection.',
+	'ACP_VC_SETTINGS_EXPLAIN'				=> 'در این بخش می توانید افزونه هایی را پیکربندی کنید که از ارسال هرزنامه های خودکار جلوگیری می کنند. این افزونه ها با به چالش کشاندن کاربران از طریق<em>CAPTCHA</em> کار می کنند، آمایشی که حل کردن آن برای کامپیوتر ها دشوار می باشد.',
+	'AVAILABLE_CAPTCHAS'					=> 'افزونه های در دسترس',
+	'CAPTCHA_UNAVAILABLE'					=> 'انتخاب افزونه مقدور نمی باشد زیرا موارد خواسته شده توسط آن فرآهم نشده است.',
+	'CAPTCHA_GD'							=> 'تصویر GD',
+	'CAPTCHA_GD_3D'							=> 'تصویر سه بعدی GD',
+	'CAPTCHA_GD_FOREGROUND_NOISE'			=> 'پارازیت پیش زمینه',
+	'CAPTCHA_GD_EXPLAIN'					=> 'از GD برای ایجاد تصاویر پیشرفته تری در مقابله با هرزنامه ها،استفاده کنید.',
+	'CAPTCHA_GD_FOREGROUND_NOISE_EXPLAIN'	=> 'با استفاده از پارازیت پیش زمینه خواندن تصاویر را دشوارتر کنید.',
+	'CAPTCHA_GD_X_GRID'						=> 'پارازیت پس زمینه در محور x',
+	'CAPTCHA_GD_X_GRID_EXPLAIN'				=> 'برای دشوارتر کردن خواندن تصویر،از داده های کمتری استفاده کنید،برای غیرفعال کردن پارازیت در محور x 0 را وارد کنید.',
+	'CAPTCHA_GD_Y_GRID'						=> 'پارازیت پیش زمینه در محور y',
+	'CAPTCHA_GD_Y_GRID_EXPLAIN'				=> 'برای دشوارتر کردن خواندن تصاویر از داده های کمتری استفاده کنید،برای غیرفعال کردن پارازیت در محور y 0 را وارد کنید.',
+	'CAPTCHA_GD_WAVE'						=> 'پیچیدگی امواج',
+	'CAPTCHA_GD_WAVE_EXPLAIN'				=> 'اضافه کردن امواچ پیچیده به تضاویر',
+	'CAPTCHA_GD_3D_NOISE'					=> 'اضافه کردن پارازیت های سه بعدی',
+	'CAPTCHA_GD_3D_NOISE_EXPLAIN'			=> 'اضافه کردن پارازیت های مختلف به این مدل',
+	'CAPTCHA_GD_FONTS'						=> 'استفاده از فونت های مختلف',
+	'CAPTCHA_GD_FONTS_EXPLAIN'				=> 'این گزینه نحوه نمایش کاراکتر ها در تصویر را مشخص می کند. می توانید از اشکال پیشفرض استفاده کنید و یا این اشکال را تغییر دهید.اضافه کردن حروف کوچک هم امکان پذیر.',
 
-	'CAPTCHA_SELECT'						=> 'Installed plugins',
-	'CAPTCHA_SELECT_EXPLAIN'				=> 'The dropdown holds the plugins recognised by the board. Grey entries are not available right now and might need configuration prior to use.',
-	'CAPTCHA_CONFIGURE'						=> 'Configure plugins',
-	'CAPTCHA_CONFIGURE_EXPLAIN'				=> 'Change the settings for the selected plugin.',
-	'CONFIGURE'								=> 'Configure',
-	'CAPTCHA_NO_OPTIONS'					=> 'This plugin has no configuration options.',
+	'CAPTCHA_FONT_DEFAULT'					=> 'پیشفرض',
+	'CAPTCHA_FONT_NEW'						=> 'اشکال جدید',
+	'CAPTCHA_FONT_LOWER'					=> 'از حروف کوچک هم استفاده کن',
+	'CAPTCHA_NO_GD'							=> 'تصویر ساده',
+	'CAPTCHA_PREVIEW_MSG'					=> 'تغییرات شما ذخیره نشد،این فقط یک آزمایش می باشد.',
+	'CAPTCHA_PREVIEW_EXPLAIN'				=> 'ظاهرا مدل انتخابی شما همین مدل میباشد.',
 
-	'VISUAL_CONFIRM_POST'					=> 'Enable spambot countermeasures for guest postings',
-	'VISUAL_CONFIRM_POST_EXPLAIN'			=> 'Requires guest users to pass the anti-spambot task to help prevent automated postings.',
-	'VISUAL_CONFIRM_REG'					=> 'Enable spambot countermeasures for registrations',
-	'VISUAL_CONFIRM_REG_EXPLAIN'			=> 'Requires new users to pass the anti-spambot task to help prevent automated registrations.',
-	'VISUAL_CONFIRM_REFRESH'				=> 'Allow users to refresh the anti-spambot task',
-	'VISUAL_CONFIRM_REFRESH_EXPLAIN'		=> 'اگر کاربر نمی تواند کد ضدروبات را بخواند، به کاربران اجازه درخواست یک کد ضدروبات جدید در هنگام ثبت نام داده شود.',
+	'CAPTCHA_SELECT'						=> 'مدل های نصب شده',
+	'CAPTCHA_SELECT_EXPLAIN'				=> 'این لیستی از مدل های کدهای تایید شناسایی شده در انجمن می باشد. مدل های خاکستری رنگ در دسترس نیستند و احتمالا باید پیکربندی و تنظیم شوند.',
+	'CAPTCHA_CONFIGURE'						=> 'پیکربندی کدهای تایید',
+	'CAPTCHA_CONFIGURE_EXPLAIN'				=> 'تغییر تنظیمات در کد تایید انتخاب شده',
+	'CONFIGURE'							=> 'پیکربندی',
+	'CAPTCHA_NO_OPTIONS'					=> 'سیستم کپچا پیکری بندی خاصی ندارد',
+
+	'VISUAL_CONFIRM_POST'					=> 'فعال سازی کد تایید در ارسال پست ها توسط مهمانان',
+	'VISUAL_CONFIRM_POST_EXPLAIN'			=> 'از مهمان گرامی نیز درخواست کد تایید جهت ارسال مطلب در سایت میشود ( در صورت فعال سازی این بخش )',
+	'VISUAL_CONFIRM_REG'					=> 'فعال سازی کد تایید هنگام ثبت نام',
+	'VISUAL_CONFIRM_REG_EXPLAIN'			=> 'کاربران در حین ثبت نام باید کد تایید را برای جلوگیری از ورود روبات های هرزنامه وارد کنند..',
+	'VISUAL_CONFIRM_REFRESH'				=> 'بارگزاری مجدد کد تایید',
+	'VISUAL_CONFIRM_REFRESH_EXPLAIN'		=> 'با فعال سازی این گزینه اگر کاربران نتوانند کد تایید موجود را به درستی بخوانند، بتوانند کد تایید جدیدی درخواست و دوباره تلاش کنند. ممکن است بعضی از مدلها از این گزینه پشتیبانی نکنند.',
 
 
 
@@ -281,25 +282,25 @@ $lang = array_merge($lang, array(
 	'COOKIE_PATH'	=> 'مسير کوکي',
 	'COOKIE_SECURE'	=> 'محافظ کوکي',
 	'COOKIE_SECURE_EXPLAIN'	=> 'در صورتی که سرور شما با SSL اجرا شده است، چنانچه این گزینه روی " غیرفعال" تنظیم شده است آنرا به " فعال "  تغییر دعید. درصورتی که این گزینه روی " فعال " تعریف شده باشد و سرور با SSL اجرا نشده باشد، نتایج سرور در مدت ریدایرکت ها با مشکل روبرو خواهد شد.',
-	'ONLINE_LENGTH'	=> 'View online time span',
-	'ONLINE_LENGTH_EXPLAIN'	=> 'Number of minutes after which inactive users will not appear in “Who is online” listings. The higher this value the greater is the processing required to generate the listing.',
+	'ONLINE_LENGTH'		=> 'مدت زمان آنلاین بودن کاربران',
+	'ONLINE_LENGTH_EXPLAIN'	=> 'تعداد دقایقی که اگر یک کاربر غیرفعال ( عدم رفرش صفحه و یا پست زدن و موارد اینچنینی ) باشد،در لیست "چه کسی حاضر است" نمایش داده نمیشود. هر چقدر این مقدار بیشتر باشد، عملکرد قسمت افراد آنلاین بهتر خواهد بود.',
 	'SESSION_LENGTH'	=> 'امتداد Session',
 	'SESSION_LENGTH_EXPLAIN'	=> 'Session پس از گذشت اين زمان برحسب ثانيه ، به انقضا مي رسند.',
-	'ACP_LOAD_SETTINGS_EXPLAIN'	=> 'Here you can enable and disable certain board functions to reduce the amount of processing required. On most servers there is no need to disable any functions. However on certain systems or in shared hosting environments it may be beneficial to disable capabilities you do not really need. You can also specify limits for system load and active sessions beyond which the board will go offline.',
+	'ACP_LOAD_SETTINGS_EXPLAIN'	=> 'در این بخش می توانید با تنظیم کردن این ایتم ها مقدار درخواست از سرورتان را کاهش دهید.که معمولا در اکثر سرور ها نیازی به چنین کاری نیست. به هر حال در بعضی از سیستم ها و هاستنگ های شیرینگ غیر فعال کردن بعضی از ایتم هایی که مورد نیازتان نیست می تواند مفید واقع شود. همچنین یه سری محدودیت هایی را برای انجمن خود اعمال کنید که اگر  سرور بیشتر از حد تایین شده بارگذاری شود، انجمن موقتا غیر فعال شود.',
 	'CUSTOM_PROFILE_FIELDS'	=> 'فیلد های سفارشی مشخصات',
 	'LIMIT_LOAD'	=> 'حدود بارگذاري سيستم',
-	'LIMIT_LOAD_EXPLAIN'	=> 'If the system’s 1-minute load average exceeds this value the board will automatically go offline. A value of 1.0 equals ~100% utilisation of one processor. This only functions on UNIX based servers and where this information is accessible. The value here resets itself to 0 if phpBB was unable to get the load limit.',
+	'LIMIT_LOAD_EXPLAIN'	=> 'اگر بارگذاری سیستم از یک دقیقه گذشته باشد انجمن شما به طور خودکار غیر فعال میشود. داده 1.0 برابر ~100% مصرف cpu می باشد. این عملکرد فقط در سرورهای UNIX based فعال است. اگر phpBB قادر به دریافت محدودیت های انجمن شما نشود، این داده به طور خودکار 0 خواهد شد.',
 	'LIMIT_SESSIONS'	=> 'وسعت session ها',
-	'LIMIT_SESSIONS_EXPLAIN'	=> 'If the number of sessions exceeds this value within a one minute period the board will go offline. Set to 0 for unlimited sessions.',
+	'LIMIT_SESSIONS_EXPLAIN'=> 'اگر تعداد seession ها از این داده عبور کرد،در کمتر از یک دقیقه انجمن بسته خواهد شد. برای نامحدود کردن تعداد seession 0 را وارد کنید.',
 	'LOAD_CPF_MEMBERLIST'	=> 'مجاز بودن استايل ها براي نمايش فيلدهاي سفارشي مشخصات در ليست کاربران',
 	'LOAD_CPF_VIEWPROFILE'	=> 'نمايش نتايج فيلد هاي سفارشي مشخصات در صفحه مشخصات کاربران',
 	'LOAD_CPF_VIEWTOPIC'	=> 'نمايش نتايج فيلد هاي سفارشي مشخصات در صفحات مباحث',
 	'LOAD_USER_ACTIVITY'	=> 'نمايش فعاليت هاي کاربران',
 	'LOAD_USER_ACTIVITY_EXPLAIN'	=> 'نمايش مباحث/انجمن هاي فعال هر کاربر در مشخصات و کنترل پنل. اين حالت نياز به غيرفعال شدن براي انجمن هاي با بالاي يک ميليون پست دارد.',
-	'RECOMPILE_STYLES'	=> 'Recompile stale style components',
-	'RECOMPILE_STYLES_EXPLAIN'	=> 'Check for updated style components on filesystem and recompile.',
+	'RECOMPILE_STYLES'	=> ' تألیف مجدد اجزای فرسوده ی قالب',
+	'RECOMPILE_STYLES_EXPLAIN'	=> 'این گزینه بروزرسانی های اجزای مختلف قالب را در سیتم های فایل کنترل کرده و آنها را تألیف می کند',
 	'YES_ANON_READ_MARKING'	=> 'فعال بودن نشانه گذاري مبحث براي مهمان ها',
-	'YES_ANON_READ_MARKING_EXPLAIN'	=> 'Stores read/unread status information for guests. If disabled, posts are always marked read for guests.',
+	'YES_ANON_READ_MARKING_EXPLAIN'	=> 'اطلاعات خوانده شده یا خوانده نشده را برای مهمان ها سیو می کند. در صورت غیر فعال بودن ان گزینه،پست ها همیشه برای مهمان ها به عنوان خوانده شده علامت گذاری میشوند.',
 	'YES_BIRTHDAYS'	=> 'فعال بودن لیست متولدین',
 	'YES_BIRTHDAYS_EXPLAIN'	=> 'در صورت فعال بودن،بايد گزينه متولدين هم فعال باشد',
 	'YES_JUMPBOX'	=> 'فعال بودن نمايش جعبه پرش',
@@ -310,38 +311,46 @@ $lang = array_merge($lang, array(
 	'YES_ONLINE_GUESTS_EXPLAIN'	=> 'فعال بودن مشاهده اطلاعات کاربران مهمان درمشاهده آنلاين ها.',
 	'YES_ONLINE_TRACK'	=> 'فعال بودن مشاهده اطلاعات آنلاين/آفلاين بودن کاربران',
 	'YES_ONLINE_TRACK_EXPLAIN'	=> 'نمايش پیام آنلاين بودن کاربران در مشخصات و صفحات مبحث ها.',
-	'YES_POST_MARKING'	=> 'Enable dotted topics',
-	'YES_POST_MARKING_EXPLAIN'	=> 'Indicates whether user has posted to a topic.',
+	'YES_POST_MARKING'		=> 'فعال سازی موضوعات علامت گذاری شده',
+	'YES_POST_MARKING_EXPLAIN'	=> 'مشخص میکند آیا کاربر موضوعی را در پست هاارسال کرده است یا نه',
 	'YES_READ_MARKING'	=> 'فعال بودن نشانه گذاري مبحث از جانب سرور',
 	'YES_READ_MARKING_EXPLAIN'	=> 'ذخيره سازي وضعيت خوانده شده/خوانده نشده در پايگاه داده ها پيش از يک کوکي.',
-		'YES_UNREAD_SEARCH'				=> 'فعال بودن جستجو برای پست های خوانده نشده.',
+	'YES_UNREAD_SEARCH'				=> 'فعال بودن جستجو برای پست های خوانده نشده.',
 	'ACP_AUTH_SETTINGS_EXPLAIN'	=> 'phpBB از پلاگین ها و ماژول های سندیت پشتیبانی می کند. اینجا شما می توانید چگونگی سندیت کاربران هنگام ورود به بورد را تنظیم کنید. در حالت پیشفرض پلاگین های DB, LDAP وApache تعبیه شده اند. همه روش ها به اطلاعات اضافه نیازی ندارند و تنها اطلاعات را در فیلدهای مربوط به روش انتخاب شده ثبت کنید.',
 	'AUTH_METHOD'	=> 'انتخاب يک روش سنديت',
+
+
 	'APACHE_SETUP_BEFORE_USE'	=> 'شما ناگزیرید که سندیت apache را پیش از تعویض phpBB به این حالت سندیت ، نصب کنید. لطفا در نظر داشته بشید که نام کاربری apache بایستی مشابه نام کاربری شما در phpBB باشد. سندیت apache تنها می تواند با mod_php بکارگرفته شود ( نه با یک نسخه CGI ) و safe_mode غیرفعال باشد..',
 	'LDAP_DN'	=> 'اساس LDAP <var>dn</var>',
-	'LDAP_DN_EXPLAIN'	=> 'This is the Distinguished Name, locating the user information, e.g. <samp>o=My Company,c=US</samp>.',
-	'LDAP_EMAIL'	=> 'نشان ايميل LDAP',
-	'LDAP_EMAIL_EXPLAIN'	=> 'Set this to the name of your user entry e-mail attribute (if one exists) in order to automatically set the e-mail address for new users. Leaving this empty results in empty e-mail address for users who log in for the first time.',
-	'LDAP_INCORRECT_USER_PASSWORD'	=> 'Binding to LDAP server failed with specified user/password.',
-	'LDAP_NO_EMAIL'	=> 'The specified e-mail attribute does not exist.',
-	'LDAP_NO_IDENTITY'	=> 'قادر به يافتن يک هويت ورود براي %s نيست.',
-	'LDAP_PASSWORD'	=> 'کلمه عبور LDAP',
-	'LDAP_PASSWORD_EXPLAIN'			=> 'Leave blank to use anonymous binding, otherwise fill in the password for the above user. Required for Active Directory Servers.<br /><em><strong>Warning:</strong> This password will be stored as plain text in the database, visible to everybody who can access your database or who can view this configuration page.</em>',
-	'LDAP_PORT'	=> 'پورت سرور LDAP',
-	'LDAP_PORT_EXPLAIN'	=> 'Optionally you can specify a port which should be used to connect to the LDAP server instead of the default port 389.',
-	'LDAP_SERVER'	=> 'نام سرور LDAP',
-	'LDAP_SERVER_EXPLAIN'	=> 'If using LDAP this is the hostname or IP address of the LDAP server. Alternatively you can specify an URL like ldap://hostname:port/',
-	'LDAP_UID'	=> 'LDAP <var>uid</var>',
-	'LDAP_UID_EXPLAIN'	=> 'This is the key under which to search for a given login identity, e.g. <var>uid</var>, <var>sn</var>, etc.',
-	'LDAP_USER'	=> 'LDAP user <var>dn</var>',
-	'LDAP_USER_EXPLAIN'	=> 'Leave blank to use anonymous binding. If filled in phpBB uses the specified distinguished name on login attempts to find the correct user, e.g. <samp>uid=Username,ou=MyUnit,o=MyCompany,c=US</samp>. Required for Active Directory Servers.',
-	'LDAP_USER_FILTER'	=> 'LDAP user filter',
-	'LDAP_USER_FILTER_EXPLAIN'	=> 'Optionally you can further limit the searched objects with additional filters. For example <samp>objectClass=posixGroup</samp> would result in the use of <samp>(&(uid=$username)(objectClass=posixGroup))</samp>',
-	'ACP_SERVER_SETTINGS_EXPLAIN'	=> '',
+	'LDAP_DN_EXPLAIN'				=> 'مشخص کننده نام و محل اطلاعات کاربری، برای مثال <samp>o=My Company,c=IR</samp>.',
+	'LDAP_EMAIL'					=> 'ایمیل LDAP',
+	'LDAP_EMAIL_EXPLAIN'			=> 'این را در نام مشخص کننده ایمیل وارد شده از جانب کاربر برای ایجاد ایمیل خودکار برای کاربر تنظیم کنید. برای خالی بودن ایمیل کاربرانی که برای اولین بار وارد می شوند،این فیلد را خالی بگذارید.',
+	'LDAP_INCORRECT_USER_PASSWORD'	=> 'ورود به سرور LDAP با کلمه عبور و نام کاربری مشخص شده نا موفق بود.',
+	'LDAP_NO_EMAIL'					=> 'ویژگی ایمیل وارد شده موجود نیست.',
+	'LDAP_NO_IDENTITY'				=> 'هویت ورود برای %s یافت نشد.',
+	'LDAP_PASSWORD'					=> 'کلمه عبور LDAP',
+	'LDAP_PASSWORD_EXPLAIN'			=> 'برای اتصال بی نام این فیلد را خالی بگذارید. در غیر این صورت برای نام کاربری ذکر شده در بالا کلمه عبوری تعریف کنید. تا سرور های دایرکتوری فعال شود.<br /><em><strong>هشدار :</strong> این کلمه عبور در قالبی متن ساده در پایگاه داده ذخیره خواهد شد. و برای همین برای هرکسی که به پایگاه داده دسترسی پیدا کند و یا به این صفحه مراجعه کند،قابل بازدید خواهد بود.</em>',
+	'LDAP_PORT'						=> 'پورت سرور LDAP',
+	'LDAP_PORT_EXPLAIN'				=> 'می توانید پورتی را برای اتصال به سرور LDAP انتخاب کنید، این پورت به جای پورت پیشفرض 389 استفاده خواهد شد.',
+	'LDAP_SERVER'					=> 'نام سرور LDAP',
+	'LDAP_SERVER_EXPLAIN'			=> 'اگر از سرور LDAP اسفتفاده می کنید،نام هاست و یا آدرس IPرا وارد کنید. به عنوان جایگزین می توانید لینکی مانند ldap://hostname:port/ تایین کنید.',
+	'LDAP_UID'						=> 'LDAP <var>uid</var>',
+	'LDAP_UID_EXPLAIN'				=> 'این گزینه کلیدی می باشد برای جستجوی هویت ورود به LDAP برای مثال <var>uid</var>, <var>sn</var>, و یا غیره ... .',
+	'LDAP_USER'						=> 'کاربر LDAP <var>dn</var>',
+	'LDAP_USER_EXPLAIN'				=> 'برای اتصال بی نام این فیلد را خالی بگذارید اگر این فیلد وارد شود،phpBB از آن برای یافتن کاربر درست استفاده خواهد کرد. برای مثال : <samp>uid=Username,ou=MyUnit,o=MyCompany,c=US</samp>. برای دایرکتوری فعال سرور ها لازم است.',
+
+	'LDAP_USER_FILTER'				=> 'فیلتر LDAP کاربران',
+        'LDAP_USER_FILTER_EXPLAIN'		=> 'جهت جستجوی عبارات و کاراکترهای مختلف میتوانید از فیلتر های بیشتری جهت جستجو استفاده فرمائید. برای مثال در جستجوی <samp>objectClass=posixGroup</samp> ، <samp>(&amp;(uid=$username)(objectClass=posixGroup))</samp> ظاهر میشود.',
+
+
+
+
+
+	'ACP_SERVER_SETTINGS_EXPLAIN'	=> 'در این بخش می توانید تنظیمات مربوط به دامنه و سرور را تنظیم کنید. اطلاعات وارد شده باید دقیق باشند. در صورت نادرست بودن ایمیل خطا هایی ظاهر خواهد شد. در حین وارد کردن دامنه ای مطمئن باشید که از پروتکل http:// استفاده کرده اید. پورت را فقط هنگامی تغییر دهید که مطمئن باشید، سرورتان از آن پورت استفاده می کند،در اغلب موارد پورت اجرایی در سرور 80 می باشد.',
 	'ENABLE_GZIP'	=> 'فعال بودن فشرده ساز GZip',
 	'ENABLE_GZIP_EXPLAIN'	=> 'فعال بودن فشرده سازي سبب كاهش فضا و سرعت بخشيدن به سايت شما خواهد شد اما مصرف CPU را در رايانه شما و كاربر افزايش خواهد داد.',
-	'FORCE_SERVER_VARS'	=> 'Force server URL settings',
-	'FORCE_SERVER_VARS_EXPLAIN'	=> 'If set to yes the server settings defined here will be used in favour of the automatically determined values.',
+	'FORCE_SERVER_VARS'	=> 'اجبار در تنظیمات URL سرور',
+	'FORCE_SERVER_VARS_EXPLAIN'	=> 'اگر گزینه بله را انتخاب کنید،سرور به صورت اتوماتیک از اطلاعات وارد شده و پیش فرض در این بخش استفاده خواهد کرد.',
 	'ICONS_PATH'	=> 'مسير ذخيره سازي نماد هاي پست',
 	'ICONS_PATH_EXPLAIN'	=> 'مسير درون پوشه phpBB شما, مثال. <samp>images/icons</samp>.',
 	'PATH_SETTINGS'	=> 'تنظيمات مسير',
@@ -361,15 +370,15 @@ $lang = array_merge($lang, array(
 	'UPLOAD_ICONS_PATH'	=> 'مسير ذخيره سازي نماد پسوندها',
 	'UPLOAD_ICONS_PATH_EXPLAIN'	=> 'مسير درون پوشه phpBB شما, مثال. <samp>images/upload_icons</samp>.',
 	'ACP_SECURITY_SETTINGS_EXPLAIN'	=> 'از اينجا شما مي توانيد تنظيمات Session ها و نقل قول هاي ورود را تعريف کنيد.',
-	'ALL'	=> 'All',
+	'ALL'	=> 'همه',
 	'ALLOW_AUTOLOGIN'	=> 'فعال بودن ورود هاي ماندگار',
 	'ALLOW_AUTOLOGIN_EXPLAIN'	=> 'با تعريف اين گزينه روي " بلي " کاربران در هر بازديد بصورت خودکار وارد بورد  مي شوند.',
 	'AUTOLOGIN_LENGTH'	=> 'دوام ورود ماندگار (با روز)',
 	'AUTOLOGIN_LENGTH_EXPLAIN'	=> 'تعداد روز هايي که ورود ماندگار از بين مي رود. عدد 0 را براي غيرفعال کردن وارد کنيد.',
 	'BROWSER_VALID'	=> 'مرورگر معتبر',
-	'BROWSER_VALID_EXPLAIN'	=> 'Enables browser validation for each session improving security.',
-	'CHECK_DNSBL'	=> 'Check IP against DNS Blackhole List',
-	'CHECK_DNSBL_EXPLAIN'			=> 'If enabled the user’s IP address is checked against the following DNSBL services on registration and posting: <a href="http://spamcop.net">spamcop.net</a> and <a href="http://www.spamhaus.org">www.spamhaus.org</a>. This lookup may take a while, depending on the server’s configuration. If slowdowns are experienced or too many false positives reported it is recommended to disable this check.',
+	'BROWSER_VALID_EXPLAIN'			=> 'این گزینه تایید مرورگر را در هر فصل به منظور بالا بردن سطح امنیت، کنترل می کند.',
+	'CHECK_DNSBL'					=> 'کنترل کننده IP در لیست سیاه DNS ',
+	'CHECK_DNSBL_EXPLAIN'			=> 'اگر این گزینه فعال شود،IP کاربران در سایت های خدمات DNSBL در حین ثبت نام و یا ارسال پست کنترل می شود. برای مثال <a href="http://spamcop.net">spamcop.net</a> و <a href="http://www.spamhaus.org">www.spamhaus.org</a>. این فرآیند کمی طول می کشد و بستگی به پیکربندی سرور دارد. اگر فعال سازی این گزینه سرعت تالار را پایین بیاورد و یا اشتباها IP ها را منع کند، این گزینه را غیرفعال کنید.',
 	'CLASS_B'	=> 'A.B',
 	'CLASS_C'	=> 'A.B.C',
 	'EMAIL_CHECK_MX'	=> 'چک کردن دامنه ايميل براي براي يافتن رکورد MX صحيح',
@@ -379,10 +388,10 @@ $lang = array_merge($lang, array(
 	'FORM_TIME_MAX'	=> 'حداکثر زمان براي ارسال پست ها',
 	'FORM_TIME_MAX_EXPLAIN'	=> 'اين زماني است که کاربر مجبور است تا پيش از آن فرم را ارسال کند. براي غير فعال کردن -1 را وارد کنيد. توجه اشته باشيد که صرف نظر از اين تنظيم ، در صورت به انتها رسيدن session فرم قادر به اشتباه شدن است.',
 	'FORM_TIME_MIN'	=> 'حداقل زمان براي ارسال فرم ها',
-	'FORM_TIME_MIN_EXPLAIN'	=> 'Submissions faster than this time are ignored by the board. Use 0 to disable.',
-	'FORM_SID_GUESTS'	=> 'Tie forms to guest sessions',
-	'FORM_SID_GUESTS_EXPLAIN'	=> 'If enabled, the form token issued to guests will be session-exclusive. This can cause problems with some ISPs.',
-		'FORWARDED_FOR_VALID'			=> 'معتبر سازی توسط هدر <var>X_FORWARDED_FOR</var>',
+	'FORM_TIME_MIN_EXPLAIN'	                => 'ثبت سریعتر این فرم در انجمن شما. برای غیر فعال کردن عدد 0 را وارد نمایید',
+	'FORM_SID_GUESTS'			=> 'فرم متصل کننده برای نشست مهمانان',
+	'FORM_SID_GUESTS_EXPLAIN'		=> 'با فعال شدن این گزینه مهمانانی که خارج از بسط مربوطه هستند این فرم نمایش داده خواهد شد.ممکن است در بعضی از ISP ها این فرم جواب ندهد..',
+	'FORWARDED_FOR_VALID'			=> 'معتبر سازی توسط هدر <var>X_FORWARDED_FOR</var>',
 	'FORWARDED_FOR_VALID_EXPLAIN'	=> 'Session ها فقط زمانی ادامه می یابند که هدر ارسالی <var>X_FORWARDED_FOR</var> با آنچه قبلا ارسال شده یکسان باشد.
 <br />
 در <var>X_FORWARDED_FOR</var>، IP اخراجی ها نیز مورد بررسی قرار می گیرد.',
@@ -395,7 +404,7 @@ $lang = array_merge($lang, array(
 	'IP_LOGIN_LIMIT_MAX_EXPLAIN'	=> 'حداکثر تعداد تلاش ناموفق برای ورود توسط یک IP قبل از فعال شدن کد ضدروبات.<br />
 برای فعال کردن کد ضد روبات به محض نخستین اشتباه، مقدار 0 را وارد کنید.',
 	'IP_LOGIN_LIMIT_TIME'			=> 'زمان انقضای تلاش برای ورود یک IP',
-	'IP_LOGIN_LIMIT_TIME_EXPLAIN'	=> 'Login attempts expire after this period.',
+	'IP_LOGIN_LIMIT_TIME_EXPLAIN'	=> 'بعد از این دوره امکان ورود کاربر میسر نخواهد بود',
 	'IP_LOGIN_LIMIT_USE_FORWARDED'	=> 'محدود کردن تلاش برای ورود توسط هدر <var>X_FORWARDED_FOR</var>',
 	'IP_LOGIN_LIMIT_USE_FORWARDED_EXPLAIN'	=> 'به جای محدود کردن تلاش ورود توسط IP، آن را با <var>X_FORWARDED_FOR</var> محدود می کند؛
 <br /><em><strong>هشدار :</strong> از این ویژگی فقط زمانی استفاده کنید که یک سرور واسط (Proxy) برایتان <var>X_FORWARDED_FOR</var> های صحیح تولید کند.</em>',
@@ -415,16 +424,16 @@ $lang = array_merge($lang, array(
 	'REF_PATH'						=> 'همچنين مسير معتبر',
 	'REFERER_VALID'					=> 'ناظر اعتبار',
 	'REFERER_VALID_EXPLAIN'			=> 'اگر اين گزينه فعال باشد،در هنگام ارسال پست،سرور/مسير انجمن بررسي خواهد شد.اين گزينه در انجمن هايي با چند نشاني يا ورودي از بيرون مشکل ساز خواهد بود.',
-		'TPL_ALLOW_PHP'					=> 'Allow php in templates',
-	'TPL_ALLOW_PHP_EXPLAIN'			=> 'If this option is enabled, <code>PHP</code> and <code>INCLUDEPHP</code> statements will be recognised and parsed in templates.',
+	'TPL_ALLOW_PHP'					=> 'مجوز فایل های php در قالب ها',
+	'TPL_ALLOW_PHP_EXPLAIN'			=> 'اگر این گزینه فعال باشد، <code>PHP</code> و <code>INCLUDEPHP</code> شناسایی شده و در قالب تجزیه خواهند شد.',
 ));
 
 // Email Settings
 $lang = array_merge($lang, array(
-	'ACP_EMAIL_SETTINGS_EXPLAIN'	=> 'This information is used when the board sends e-mails to your users. Please ensure the e-mail address you specify is valid, any bounced or undeliverable messages will likely be sent to that address. If your host does not provide a native (PHP based) e-mail service you can instead send messages directly using SMTP. This requires the address of an appropriate server (ask your provider if necessary). If the server requires authentication (and only if it does) enter the necessary username, password and authentication method.',
+	'ACP_EMAIL_SETTINGS_EXPLAIN'	=> 'این اطلاعات، ایمیل های ارسالی به کاربران را تنظیم می کنند، اطمینان حاصل کنید که ایمیل معتبری را وارد کرده اید. این ایمیل منعکس کننده هر گونه خطا در ارسال ایمیل ها به کاربران خواهد بود. اگر سرور ایمیلی را در دسترس ندارید (بر پایه ی PHP)  می توانید از تنظیمات SMTP استفاده کنید، برای جزئیات با سرویس خدمات دهی ایمیلتان تماس بگیرید. اگر سرور نیازمند تایید باشد،کلمه عبور و نام کاربری مربوطه را وارد کرده و نیز روش تایید را مشخص کنید.',
 
-	'ADMIN_EMAIL'					=> 'Return e-mail address',
-	'ADMIN_EMAIL_EXPLAIN'			=> 'This will be used as the return address on all e-mails, the technical contact e-mail address. It will always be used as the <samp>Return-Path</samp> and <samp>Sender</samp> address in e-mails.',
+	'ADMIN_EMAIL'					=> 'ایمیل برگشتی',
+	'ADMIN_EMAIL_EXPLAIN'			=> 'این ایمیل در تمامی ایمیل ها و از جمله ایمیل پشتیبانی فنّی مورد استفاده قرار خواهد گرفت. همچنین در <samp>مسیر برگشتی</samp> و <samp>فرستنده</samp> ایمیل ها مورد استفاده قرار خواهد گرفت.',
 		
 	'BOARD_EMAIL_FORM'	=> 'کاربران ايميل ها را توسط بورد ارسال کنند',
 	'BOARD_EMAIL_FORM_EXPLAIN'	=> 'بجاي مشاهده ايميل کاربران ، از طريق بورد براي آنها ايميل ارسال مي کنند.',
@@ -478,88 +487,43 @@ $lang = array_merge($lang, array(
 		
 	//phpBB 3.0.5 Additional by www.Maghsad.com	
 	
-		'CAPTCHA_GD_WAVE'						=> 'GD CAPTCHA wave distortion',
-	'CAPTCHA_GD_WAVE_EXPLAIN'				=> 'This applies a wave distortion to the CAPTCHA.',
-	'CAPTCHA_GD_3D_NOISE'					=> 'Add 3D-noise objects',
-	'CAPTCHA_GD_3D_NOISE_EXPLAIN'			=> 'This adds additional objects to the CAPTCHA, over the letters.',
-	'CAPTCHA_GD_FONTS'						=> 'Use different fonts',
-	'CAPTCHA_GD_FONTS_EXPLAIN'				=> 'This setting controls how many different letter shapes are used. You can just use the default shapes or introduce altered letters. Adding lowercase letters is also possible.',
-	'CAPTCHA_FONT_DEFAULT'					=> 'Default',
-	'CAPTCHA_FONT_NEW'						=> 'New Shapes',
-	'CAPTCHA_FONT_LOWER'					=> 'Also use lowercase',
+
 	
-	//-------------------------------//
-	
-	'VISUAL_CONFIRM_REFRESH'				=> 'Enable users to refresh the confirmation image',
-	'VISUAL_CONFIRM_REFRESH_EXPLAIN'		=> 'Allows users to request new confirmation codes, if they are unable to solve the VC during registration.',
-	//END phpBB 3.0.5 Additional by www.Maghsad.com
 	
 	
 	//START 3.0.5 to 3.0.6 changes - www.phpBB.Maghsad.com
 	
-		'ALLOW_PM_REPORT'			=> 'Allow users to report private messages',
-	'ALLOW_PM_REPORT_EXPLAIN'	=> 'If this setting is enabled, users have the option of reporting a private message they have received or sent to the board’s moderators. These private messages will then be visible in the Moderator Control Panel.',
+		'ALLOW_PM_REPORT'			=> 'مجوز جهت گزارش پیغام های خصوصی خلاف',
+	'ALLOW_PM_REPORT_EXPLAIN'	=> 'اگر این گزینه فعال باشد کاربران می توانند پیغام های خصوصی دریافت شده را به مدیران یا ناظمان گزارش دهند،پغام های گزارش شده در کنترل پنل مدیریت برای مدیران قابل رویت میباشد.',
 	'ALLOW_QUICK_REPLY'			=> 'اجازه پاسخ سریع',
 	'ALLOW_QUICK_REPLY_EXPLAIN'	=> 'اگر این گزینه غیر فعال شود، امکان ارسال پاسخ سریع در تمام انجمن ها غیر فعال می شود؛ اگر فعال باشد، با توجه به سطوح دسترسی هر فوروم این گزینه فعال یا غیرفعال است.',
 	'ALLOW_QUICK_REPLY_BUTTON'	=> 'در تمام انجمن ها پاسخ سریع را فعال کن',
 
-//////////////////////////////////////////////
+
 
 
 	'ALLOW_AVATARS'					=> 'فعال سازی آواتار (عکس کاربر)',
 	'ALLOW_AVATARS_EXPLAIN'			=> 'فعال سازی امکان استفاده آواتار (نماد) برای کاربران<br />غیرفعال کردن این امکان سبب عدم نمایش آواتار افراد در انجمن می شود اما همچنان می تواند از کنترل پنل کاربری آواتار خود را دانلود کند.',
-////////////////////////////////////////////
+
 
 	'ALLOW_REMOTE_UPLOAD'			=> 'آپلود آواتار از لینک',
 	'ALLOW_REMOTE_UPLOAD_EXPLAIN'	=> 'اجازه آپلود آواتار از لینک موجود در سایت دیگر داده شود.',
 
-////////////////////////////////////////////
+
 	'DELETE_TIME'					=> 'محدودیت زمان حذف',
-	'DELETE_TIME_EXPLAIN'			=> 'مدت زمانی که کاربر می تواند پس از ایجاد یک پست جدید، آن را حذف کند.<br />برای غیر فعال کردن مقدار 0 را وارد کنید.',	//////////////////////////////////////////	
+	'DELETE_TIME_EXPLAIN'			=> 'مدت زمانی که کاربر می تواند پس از ایجاد یک پست جدید، آن را حذف کند.<br />برای غیر فعال کردن مقدار 0 را وارد کنید.',		
 		
-			'MIN_CHAR_LIMIT'				=> 'Minimum characters per post/message',
+			'MIN_CHAR_LIMIT'				=> 'حداقل تعداد کاراکتر مورد نیاز در هر پست/پیغام',
 	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'حداقل تعداد کاراکترهای لازم برای ارسال یک پست/پسام خصوصی. حداقل این مقدار 1 است.',
 				
-//////////////////////////////////////////
+
 
 	'SMILIES_PER_PAGE'				=> 'شکلک ها در هر صفحه',
 
-//////////////////////////////////////////////////////////////////
-
-	'ACP_VC_SETTINGS_EXPLAIN'				=> 'Here you can select and configure CAPTCHA plugins, which implement various ways to reject registration attempts from so-called spambots.',
-	'AVAILABLE_CAPTCHAS'					=> 'Available plugins',
-	'CAPTCHA_UNAVAILABLE'					=> 'The CAPTCHA cannot be selected as its requirements are not met.',
-	'CAPTCHA_GD'							=> 'GD CAPTCHA',
-	'CAPTCHA_GD_3D'							=> 'GD 3D Captcha',
-////////////////////////////////////////////////////////////////////
-
-	'CAPTCHA_NO_GD'							=> 'CAPTCHA without GD',
-	'CAPTCHA_PREVIEW_MSG'					=> 'Your changes to the visual confirmation setting were not saved. This is just a preview.',
-	'CAPTCHA_PREVIEW_EXPLAIN'				=> 'The CAPTCHA as it would look like using the current selection.',
-
-	'CAPTCHA_SELECT'						=> 'Installed CAPTCHA plugins',
-	'CAPTCHA_SELECT_EXPLAIN'				=> 'The dropdown holds the CAPTCHA plugins recognized by the board. Gray entries are not available right now and might need configuration prior to use.',
-	'CAPTCHA_CONFIGURE'						=> 'Configure CAPTCHAs',
-	'CAPTCHA_CONFIGURE_EXPLAIN'				=> 'Change the settings for the selected CAPTCHA.',
-	'CONFIGURE'								=> 'Configure',
-	'CAPTCHA_NO_OPTIONS'					=> 'This CAPTCHA has no configuration options.',
-
-	'VISUAL_CONFIRM_POST'					=> 'Enable visual confirmation for guest postings',
-	'VISUAL_CONFIRM_POST_EXPLAIN'			=> 'Requires anonymous users to enter a random code matching an image to help prevent mass postings.',
-	'VISUAL_CONFIRM_REG'					=> 'Enable visual confirmation for registrations',
-	'VISUAL_CONFIRM_REG_EXPLAIN'			=> 'Requires new users to enter a random code matching an image to help prevent mass registrations.',
-	'VISUAL_CONFIRM_REFRESH'				=> 'Enable users to refresh the confirmation image',
-	'VISUAL_CONFIRM_REFRESH_EXPLAIN'		=> 'Allows users to request new confirmation codes, if they are unable to solve the VC during registration. Some plugins might not support this option.',
 
 
-//////////////////////////////////////////////////////////////////////
 
-	'ENABLE_GZIP_EXPLAIN'		=> 'Generated content will be compressed prior to sending it to the user. This can reduce network traffic but will also increase CPU usage on both server and client side. Requires zlib PHP extension to be loaded.',
-/////////////////////////////////////////////////////////////////////
 
-	'ENABLE_EMAIL_EXPLAIN'			=> 'If this is set to disabled no e-mails will be sent by the board at all. <em>Note the user and admin account activation settings require this setting to be enabled. If currently using “user” or “admin” activation in the activation settings, disabling this setting will require no activation of new accounts.</em>',
-
-/////////////////////////////////////////////////////////////////////
 
 				
 	
@@ -589,29 +553,29 @@ $lang = array_merge($lang, array(
 
 
 
-	'ACP_FEED_OVERALL'					=> 'Enable board-wide feed',
-	'ACP_FEED_OVERALL_EXPLAIN'			=> 'Board-wide new posts.',
+	'ACP_FEED_OVERALL'					=> 'فعال سازی خوراک انجمن ها',
+	'ACP_FEED_OVERALL_EXPLAIN'			=> 'فعال سازی خوراک برای پست های جدید',
 	'ACP_FEED_FORUM'					=> 'فعال سازی خوراک (Feed) برای هر انجمن',
 	'ACP_FEED_FORUM_EXPLAIN'			=> 'پست های جدید فقط یک انجمن',
 	'ACP_FEED_TOPIC'					=> 'فعال سازی خوراک (Feed) برای هر موضوع',
 	'ACP_FEED_TOPIC_EXPLAIN'			=> 'پست های جدید یک موضوع',
 
-	'ACP_FEED_TOPICS_NEW'				=> 'Enable new topics feed',
-	'ACP_FEED_TOPICS_NEW_EXPLAIN'		=> 'Enables the “New Topics” feed, which displays the last created topics including the first post.',
-	'ACP_FEED_TOPICS_ACTIVE'			=> 'Enable active topics feed',
-	'ACP_FEED_TOPICS_ACTIVE_EXPLAIN'	=> 'Enables the “Active Topics” feed, which displays the last active topics including the last post.',
+	'ACP_FEED_TOPICS_NEW'				=> 'فعال سازی خوراک موضوعات جدید',
+	'ACP_FEED_TOPICS_NEW_EXPLAIN'		=> 'فعال سازی خوراک "موضوعات جدید" که شامل جدیدترین موضوعات همراه با موضوع اول است.',
+	'ACP_FEED_TOPICS_ACTIVE'			=> 'فعال سازی خوراک برای موضوعات فعال',
+	'ACP_FEED_TOPICS_ACTIVE_EXPLAIN'	=> ' فعال سازی خوراک "موضوعات فعال" که شامل فعال ترین موضوعات است.',
 	'ACP_FEED_NEWS'						=> 'خوراک (Feed) اخبار',
 	'ACP_FEED_NEWS_EXPLAIN'				=> 'استفاده از پست اول این انجمن ها به عنوان خوراک (Feed) اخبار، برای انتخاب چندگانه میتوانید از ctrl و کلیک استفاده کنید.',
 
 	'ACP_FEED_OVERALL_FORUMS'			=> 'فعال سازی خوراک (Feed) سراسری انجمن',
 	'ACP_FEED_OVERALL_FORUMS_EXPLAIN'	=> 'این خوراک (Feed) تمامی پست های موجود در انجمن های شما را نمایش خواهد داد.',
-	'ACP_FEED_HTTP_AUTH'				=> 'Allow HTTP Authentication',
-	'ACP_FEED_HTTP_AUTH_EXPLAIN'		=> 'Enables HTTP authentication, which allows users to receive content that is hidden to guest users by adding the <samp>auth=http</samp> parameter to the feed URL. Please note that some PHP setups require additional changes to the .htaccess file. Instructions can be found in that file.',
+	'ACP_FEED_HTTP_AUTH'				=> 'تاییدیه برای HTTP',
+	'ACP_FEED_HTTP_AUTH_EXPLAIN'		=> 'ویژگی ای که به کاربران اجازه می دهد تا با اضافه کردن پارامتر <samp>auth=http</samp> به URL خوراک محتوایی را ببینند که برای مهمانان قابل مشاهده نیست. لطفا توجه داشته باشید که بعضی از نصب های PHP ممکن است برای اعمال این تنظیمات نیازمند تغییراتی در فایل .htaccess باشند.',
 	'ACP_FEED_ITEM_STATISTICS'			=> 'نمایش آمار هر فید مانند تعداد بازدید ها و ...',
 	'ACP_FEED_ITEM_STATISTICS_EXPLAIN'	=> 'نمایش اطلاعات آماری در زیر موضوعات خوراک (Feed) مانند تعداد بازدید و ...',		
 		
-	'ACP_FEED_EXCLUDE_ID'				=> 'Exclude these forums',
-	'ACP_FEED_EXCLUDE_ID_EXPLAIN'		=> 'Content from these will be <strong>not included in feeds</strong>. Select no forum to pull data from all forums.<br />Select/Deselect multiple forums by holding <samp>CTRL</samp> and clicking.',
+	'ACP_FEED_EXCLUDE_ID'				=> 'اغماض کردن این انجمن ها',
+	'ACP_FEED_EXCLUDE_ID_EXPLAIN'		=> 'محتوای این انجمن ها .<strong>در خوراک نمایش داده نخواهند شد</strong> برای قراردادن اطلاعات تمامی انجمن ها،انجمنی را انتخاب نکنید.<br />با نگه داشتن <samp>CTRL</samp> و کلیک بر روی نام های انجمن ها می توانید به سادگی چند مورد را همزمان انتخاب و یا لغو انتخاب کنید.',
 		
 		
 		
